@@ -34,7 +34,7 @@ class Tempest:
                         logging.info("Received observation message...")
                         self._send_graphite(message['obs'][0])
                 except:
-                    logging.debug(json.dumps(message))
+                    logging.warn(json.dumps(message))
                 
 
     def _send_graphite(self, metrics):
